@@ -1,6 +1,6 @@
-from django.test import TestCase
+from django.test import TestCase, override_settings
 
-from django_bootstrap5.core import get_bootstrap_setting
+from bootstrap5.bootstrap import get_bootstrap_setting
 
 
 class SettingsTest(TestCase):
@@ -10,3 +10,4 @@ class SettingsTest(TestCase):
         # Override a setting
         with self.settings(BOOTSTRAP5={"SETTING_DOES_NOT_EXIST": "exists now"}):
             self.assertEqual(get_bootstrap_setting("SETTING_DOES_NOT_EXIST"), "exists now")
+
